@@ -4,7 +4,7 @@ use warnings;
 no warnings qw(uninitialized redefine);
 
 package Apache::Wyrd::Cookie;
-our $VERSION = '0.95';
+our $VERSION = '0.96';
 use vars qw(@ISA);
 
 my $have_apr = 1;
@@ -96,6 +96,10 @@ Barry King E<lt>wyrd@nospam.wyrdwright.comE<gt>
 
 General-purpose HTML-embeddable perl object
 
+=item Apache::Cookie
+
+Cookies under Apache
+
 =back
 
 =head1 LICENSE
